#
# spec file for package python-argh
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-argh
Version:        0.28.1
Release:        1.3
Summary:        An argparse wrapper
License:        LGPL-3.0-or-later
URL:            https://github.com/neithere/argh/
Source:         https://files.pythonhosted.org/packages/source/a/argh/argh-%{version}.tar.gz
BuildRequires:  %{python_module flit-core}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%python_subpackages

%description
This Python module provides a wrapper for argparse with support for hierarchical
commands that can be bound to modules or classes.

Features that argh adds to argparse:

* mark a function as a CLI command and specify its arguments before the parser
  is instantiated;
* nested commands made easy: no messing with subparsers (though they are of
  course used under the hood);
* infer agrument type from the default value;
* infer command name from function name;
* add an alias root command help for the --help argument;
* enable passing unwrapped arguments to certain functions instead of a
  argparse.Namespace object.

Argh is fully compatible with argparse. argh-agnostic and argh-aware code
can be mixed. Keep in mind that argh.dispatch does some extra
work that a custom dispatcher may not do.

%prep
%autosetup -p1 -n argh-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# do not run test_integration, which requires dropped iocapture
rm tests/test_integration.py
%pytest -v

%files %{python_files}
%doc README.rst
%{python_sitelib}/argh/
%{python_sitelib}/argh-%{version}.dist-info

%changelog
* Fri Jun  2 2023 pgajdos@suse.com
- version update to 0.28.1
  Version 0.28.1
  - -------------
  - Fixed bugs in tests (#171, #172)
  Version 0.28.0
  - -------------
  A major cleanup.
  Backward incompatible changes:
  - Dropped support for Python 2.7 and 3.7.
  Deprecated features, to be removed in v.0.30:
  - `argh.assembling.SUPPORTS_ALIASES`.
  - Always `True` for recent versions of Python.
  - `argh.io.safe_input()` AKA `argh.interaction.safe_input()`.
  - Not relevant anymore.  Please use the built-in `input()` instead.
  - argument `pre_call` in `dispatch()`.
  - Argument help as annotations.
  - Annotations will only be used for types after v.0.30.
  - Added deprecation warnings for some arguments deprecated back in v.0.26.
  Version 0.27.2
  - -------------
  Minor packaging fix:
  * chore: include file required by tox.ini in the sdist (#155)
  Version 0.27.1
  - -------------
  Minor building and packaging fixes:
  * docs: add Read the Docs config (#160)
  * chore: include tox.ini in the sdist (#155)
  Version 0.27.0
  - -------------
  This is the last version to support Python 2.7.
  Backward incompatible changes:
  - Dropped support for Python 2.6.
  Enhancements:
  - Added support for Python 3.7 through 3.11.
  - Support introspection of function signature behind the `@wraps` decorator
    (issue #111).
  Fixed bugs:
  - When command function signature contained ``**kwargs`` *and* positionals
    without defaults and with underscores in their names, a weird behaviour could
    be observed (issue #104).
  - Fixed introspection through decorators (issue #111).
  - Switched to Python's built-in `unittest.mock` (PR #154).
  - Fixed bug with `skip_unknown_args=True` (PR #134).
  - Fixed tests for Python 3.9.7+ (issue #148).
  Other changes:
  - Included the license files in manifest (PR #112).
  - Extended the list of similar projects (PR #87).
  - Fixed typos and links in documentation (PR #110, #116, #156).
  - Switched CI to Github Actions (PR #153).
- deleted patches
  - python-argh-no_mock.patch (upstreamed)
  - support-py39.patch (upstreamed)
* Thu Mar 10 2022 pgajdos@suse.com
- do not use python-mock for testing
- added patches
  fix https://github.com/neithere/argh/issues/152
  + python-argh-no_mock.patch
* Wed Sep 22 2021 Steve Kowalik <steven.kowalik@suse.com>
- Add patch support-py39.patch:
  * Deal with Python 3.9.x changes in argparse.
* Mon May 17 2021 pgajdos@suse.com
- use %%pytest macro
* Tue May  7 2019 Tomáš Chvátal <tchvatal@suse.com>
- Do not use symlinks on fdupes
* Mon Mar  4 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.26.2:
  * no changelog available
- Drop no longer needed python-argh-0.26.1-fix-testsuite.patch
* Wed Dec  5 2018 Jan Engelhardt <jengelh@inai.de>
- Trim rhetorics from descriptions.
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Mon Apr 24 2017 toddrme2178@gmail.com
- Fix source URL
- Various small spec file cleanups.
* Sun Apr 23 2017 aloisio@gmx.com
- Converted to single-spec
- Added python-argh-0.26.1-fix-testsuite.patch
- Enabled tests
* Sun Apr 19 2015 benoit.monin@gmx.fr
- update to version 0.26.1
  * no changelog available
- update project URL
- package README.rst instead of README
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Wed Sep 25 2013 p.drouand@gmail.com
- Update to version 0.23.3
  + No changelog available
* Thu Mar  7 2013 darin@darins.net
- Update to verios 0.23.0
  + Upstream provides no changelog
* Fri Nov 23 2012 saschpe@suse.de
- Update to version 0.17.2:
  + Upstream provides no changelog
* Wed Jun  6 2012 os-dev@jacraig.com
- Update to version 0.15.1:
  + Upstream provides no changelog
* Tue Jan 31 2012 saschpe@suse.de
- Initial version
